/*  -------------------------------------------------------------------------- 
    Program  :  NP16.sas

    Author   :  Perry Watts
    Date     :  Thursday, July 12, 2007

    Project  :  N07 Better Bar Chart Paper (NP16)

    Purpose  :  Create the plots to be included in the paper and presentation

    Notes    :  Full Reference:
                "Building a Better Bar Chart with SAS/Graph Software."
                Proceedings of the 20th Annual Northeast SAS Users Group Conference. 
                Baltimore, MD, 2007, paper #NP16.

    Input    :  Mostly Miron's data reproduced by permission from SI
    Output   :  Figures (emf files)
    ------------------------------------------------------------------------  */
footnote1;
%put FULLPATH: %sysget(SAS_EXECFILEPATH);
libname N07 'C:\N07\BetterBarChart\Data';
options mautosource;
options sasautos=(sasautos  'c:\n07\Macros');

goptions reset=goptions;
pattern1;
pattern2;
pattern3;
axis1;
axis2;
axis3;

goptions device=emf gunit=pct rotate=landscape ftext="Arial";

proc format;
  value $dpt2Lfm 'ACCOUNTS'='Accounting' 'MARKET'='Marketing' 'PAYROLL'= 'Payroll'
                  'SHIP'='Shipping' other=' ';
  /* MONTH FORMAT - TO GET THE RIGHT ORDER */
  value monthFmt 1=Jan 2=Feb 3=Mar 4=Apr 5=May 6=Jun 7=Jul 8=Aug 9=Sep 10=Oct 11=Nov 12=Dec;
  picture pctIntfm (round) low-high='009%';
  picture pctRfm (round) low-high='009.9%';
  value hospFm 1= H1723NM 2= H2833PA 3= H3619CT 4= H4621MI 5= H5727MN;
run;

/* First two graphs from Beginning paper:*/ 
title1 "Count of Meetings by Department";
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt1.emf';
goptions htext=10pt htitle=12pt gsfname=chrt;
proc gchart data=N07.meetings;
  title2 "(Default Width Bars)";
  vbar dept;
run;
quit;

title2 "(Fatter Bars)";
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt2.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;
proc gchart data=N07.meetings;
  vbar dept/width=15;
run;
quit;

/* Problems with a few bars: default width bars with reasonably sized text causes line wrap*/
pattern1 color=grayCC;
axis1 order=(0 to 14 by 2) minor=(n=1)
 label=(a=90 f="Arial/Bold" "Frequency") ;
axis2 label=(f="Arial/Bold" "Department");
title1 'Number of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt3.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;
proc gchart data=N07.meetings;
 vbar dept /
  noframe raxis=axis1 maxis=axis2
  coutline=black woutline=1;
run;
quit;

/* Fix the problem with Width=9, but the graph still needs to be cropped */
pattern1 color=grayCC;
axis1 order=(0 to 14 by 2) minor=(n=1)
 label=(a=90 f="Arial/Bold" "Frequency") ;
axis2 label=(f="Arial/Bold" "Department");
title1 'Number of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt4.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;
proc gchart data=N07.meetings;
  vbar dept /
   width=9 noframe
   raxis=axis1 maxis=axis2
   coutline=black woutline=1;
run;
quit;

  /* Use the entire axis - with a calculated value for WIDTH*/
%let result = %getBarInfo(Xorigin=15, SpaceSz=2, GspaceSz=0, Ngrps=0, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%put !!**!! width=&width;

pattern1 color=grayCC;
axis1 order=(0 to 14 by 2) minor=(n=1) label=(a=90 f="Arial/Bold" "Frequency");
axis2 label=(f="Arial/Bold" "Department") origin=(15PCT, 20PCT);
title1 move=(+9Pct,+0Pct) 'Number of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt5.emf';
goptions htext=17pt htitle=19pt gsfname=chrt;
proc gchart data=N07.meetings;
  vbar dept /
     width=&width noframe
     raxis=axis1 maxis=axis2
     coutline=black woutline=1;
run;
quit;

/* 9 bar charts:*/
/* Easy WIDTH= solution. DO NOT USE ORIGIN= OR OFFSET= IN THE AXIS STATEMENTS*/
pattern1 color=CXAC4040; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
legend1
  across=1 shape=bar(3,2) label=("Room" h=12 pt position=Left j=c)
  position=(top inside left) mode=share
  value=(h=11pt 'B100' 'C301' 'C339');

axis1 label=(a=90 f="Arial/Bold" "Frequency") 
 order=(0 to 6 by 2) minor=(n=1) offset=(,8pct);
axis2 label=none value=none;
axis3 label=("Dept");

title1 move=(+5pct,+0pct) 'Number of Meetings by Department and Room';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt6_0.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.Meetings;
  vbar room / WIDTH=50
    type=FREQ
    Group=Dept patternID=subgroup noframe
    legend=legend1 subgroup=room raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
run;
quit;

/* 9-bar chart with macro call.*/
%let result = %getBarInfo(Xorigin=15, SpaceSz=2, GspaceSz=3, Ngrps=3, Nbars=9, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');
%put !!**!! width=&width gspace=&gspace;
pattern1 color=CXAC4040; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
legend1
  across=1 shape=bar(3,2) label=("Room" h=12 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=11pt 'B100' 'C301' 'C339');

axis1 label=(a=90 f="Arial/Bold" "Frequency") 
 order=(0 to 6 by 2) minor=(n=1) origin=(15pct, 10pct) offset=(,8pct);
axis2 label=none value=none origin=(15pct, 10pct);
axis3 label=("Dept") offset=(0.5pct, 0.5pct);

title1 move=(+9pct,+0pct) 'Number of Meetings by Department and Room';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt6_1.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.Meetings;
  vbar room /
    type=FREQ width=&width gspace=&gspace
    Group=Dept patternID=subgroup noframe
    legend=legend1 subgroup=room raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
run;
quit;

/* 16 bars*/
/* Small value for GSpaceSz:*/

%let result = %getBarInfo(Xorigin=15, SpaceSz=0.5, GspaceSz=1, Ngrps=4, Nbars=16, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');
%put !!**!! width=&width gspace=&gspace;

pattern1 color=CXAC4040; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
pattern4 color=CX4040AC;
legend1
  across=1 shape=bar(3,2) label=("Room" h=11 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=9pt 'B100' 'C301' 'C339' 'D410');

axis1 label=(a=90 f="Arial/Bold" "Frequency") 
 order=(0 to 8 by 2) minor=(n=1) origin=(15pct, 10pct) offset=(,4pct);
axis2 label=none value=none origin=(15pct, 10pct);
axis3 label=("Dept") offset=(0.5 pct, 0.5 pct);

title1 move=(+9pct,+0pct) 'Number of Meetings by Room and Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt7_0.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.moreMeetings;
  vbar room /
    width=&width gspace=&gspace type=FREQ
    Group=Dept patternID=subgroup noframe
    legend=legend1 subgroup=room raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
run;
quit;

/* Larger value for GSpaceSz GROUP LABEL LEFT IN (When it is removed graph expands to take up space):*/
%let result = %getBarInfo(Xorigin=15, SpaceSz=1, GspaceSz=4, Ngrps=4, Nbars=16, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');
%put !!**!! width=&width gspace=&gspace;

pattern1 color=CXAC4040; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
pattern4 color=CX4040AC;
legend1
  across=1 shape=bar(3,2) label=("Room" h=11 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=9pt 'B100' 'C301' 'C339' 'D410');

axis1 label=(a=90 f="Arial/Bold" "Frequency") 
 order=(0 to 8 by 2) minor=(n=1) origin=(15pct, 10pct) offset=(,4pct);
axis2 label=none value=none origin=(15pct, 10pct);
axis3 label=("Dept") offset=(0.5 pct, 0.5 pct);

title1 move=(+9pct,+0pct) 'Number of Meetings by Room and Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt7_1.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.moreMeetings;
  vbar room /
    width=&width gspace=&gspace type=FREQ
    Group=Dept patternID=subgroup noframe
    legend=legend1 subgroup=room raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
run;
quit;

  /* LEGENDS:*/

  /* SUBGROUP CHARTS*/
  /* With a legend */
%let result = %getBarInfo(Xorigin=15, SpaceSz=3, GspaceSz=0, Ngrps=1, Nbars=4, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=graydd; 
pattern2 color=graybb;
legend1
  across=1 shape=bar(3,2) label=(j=l h=12pt position=(top left)"Meeting Length")
  position=(top inside left) mode=share
  value=(h=11pt j=l 'Short' j=l 'Long');

axis1 label=(a=90 f="Arial/Bold" "Total # Meetings") 
 order=(0 to 20 by 5) minor=(n=1) origin=(15pct, 17pct) offset=(,8pct);
axis2 label=(f="Arial/Bold" "Department") origin=(15pct, 17pct);

title1 move=(+9pct,+0pct) 'Length of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt8_1.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.moreMeetings;
  vbar Dept /
    width=&width type=FREQ inside=freq outside=freq
    subgroup=hrGrp legend=legend1 
    noframe raxis=axis1 maxis=axis2
    coutline=black woutline=1;
run;
quit;

  /* With NO legend (MIN/MAX Chart) */
%let result = %getBarInfo(Xorigin=15, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=12, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

 /* CREATE MIN/MAX CHART */
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt8_2.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

pattern1 color=Blue;
pattern2 color=Red;
axis1 label=(a=90 f="Arial/Bold" 'Temperature (Centigrade)') minor=(n=4) order=(-30 to 30 by 10) origin=(15pct, 17pct);
axis2 label=(f="Arial/Bold" 'Month') origin=(15pct, 17pct);
title1 move=(+9pct,+0pct) 'Average Temperature in Minneapolis';
title2 move=(+9pct,+0pct) '(by Month)';

 proc gchart data=n07.MplsWeather; 
  vbar month / discrete noframe
    width=&width type=sum sumvar=TC
    subgroup=AboveZeroYvN nolegend
    raxis=axis1 maxis=axis2
    autoref clipref cref=graybb
    coutline=black woutline=1; 
  format month monthfmt.;
run;
quit;

  /* Midpoint Charts*/
  /* With a Legend*/
%let result = %getBarInfo(Xorigin=15, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=blue; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
legend1
  across=1 shape=bar(3,2) label=None
  position=(top inside left) mode=share
  value=(h=13pt 'Accounting' 'Marketing' 'Shipping');
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
  order=(0 to 14 by 2) minor=(n=1) origin=(15pct, 4pct) offset=(,1pct);
axis2 value=NONE label=NONE origin=(15pct, 4pct);
title1 move=(+9pct,+0pct) 'Number of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt9_1.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.meetings;
  vbar dept / noframe
    width=&width type=FREQ outside=FREQ
    legend=legend1 subgroup=dept 
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
run;
quit;

  /* With NO Legend*/
%let result = %getBarInfo(Xorigin=15, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=blue; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
  order=(0 to 14 by 2) minor=(n=1) origin=(15pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(15pct, 17pct);
title1 move=(+9pct,+0pct) 'Number of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt9_2.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.meetings;
  vbar dept / noframe
    width=&width type=FREQ outside=FREQ
    patternId=midpoint
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
    format dept $dpt2Lfm.;
run;
quit;

/* Group Charts */
/* With a legend */
/* 9-bar chart with macro call.*/
%let result = %getBarInfo(Xorigin=15, SpaceSz=2, GspaceSz=3, Ngrps=3, Nbars=9, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXAC4040; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
legend1
  across=1 shape=bar(3,2) label=NONE
  position=(top inside left) mode=share
  value=(h=13pt 'Accounting' 'Marketing' 'Shipping');

axis1 label=(a=90 f="Arial/Bold" "Frequency") 
 order=(0 to 6 by 2) minor=(n=1) origin=(15pct, 10pct) offset=(,8pct);
axis2 label=none value=none origin=(15pct, 10pct);
axis3 label=("Room") offset=(0.5 pct, 0.5 pct);

title1 move=(+9pct,+0pct) 'Number of Meetings by Room and Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt10_1.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.Meetings;
  vbar Dept /noframe
    type=FREQ width=&width gspace=&gspace
    subgroup=dept legend=legend1
    Group=Room raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
run;
quit;

/* With NO legend */
/* 9-bar chart with macro call.*/
%let result = %getBarInfo(Xorigin=15, SpaceSz=2, GspaceSz=3, Ngrps=3, Nbars=9, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');
pattern1 color=CXAC4040; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
axis1 label=(a=90 f="Arial/Bold" "Frequency") 
 order=(0 to 6 by 2) minor=(n=1) origin=(15pct, 17pct) offset=(,1pct);
axis2 label=("Room") origin=(15pct, 17pct);
axis3 label=("Dept") offset=(0.5 pct, 0.5 pct);

title1 move=(+9pct,+0pct) 'Number of Meetings by Department and Room';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt10_2.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.Meetings;
  vbar Room /
    type=FREQ width=&width gspace=&gspace
    Group=Dept patternID=group noframe
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
    format dept $dpt2Lfm.;
run;
quit;

/* With NO legend AND NO &WIDTH*/
/* 9-bar chart with macro call.*/

pattern1 color=CXAC4040; 
pattern2 color=graycc; 
pattern3 color=CX40AC40;
axis1 label=(a=90 f="Arial/Bold" "Frequency") 
 order=(0 to 6 by 2) minor=(n=1) origin=(15pct, 30pct) offset=(,1pct);
axis2 label=("Room") origin=(15pct, 30pct);
axis3 label=("Dept") offset=(0.5 pct, 0.5 pct);

title1 move=(+9pct,+0pct) 'Number of Meetings by Department and Room';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt10_3.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.Meetings;
  vbar Room /
    type=FREQ gspace=&gspace
    Group=Dept patternID=group noframe
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
    format dept $dpt2Lfm.;
run;
quit;

  /* SUMMARY DATA SIMPLIFIES PROCESSING */
%let result = %getBarInfo(Xorigin=17, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=graycc; 
axis1 label=(a=90 f="Arial/Bold" "Number of Meetings")
  order=(0 to 20 by 5) minor=(n=1) origin=(17pct, 18pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(17pct, 18pct);
title1 move=(+9pct,+0pct) 'Number of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt11_1.emf';
goptions htext=15pt htitle=17pt gsfname=chrt;

proc gchart data=N07.MeetingsMoreClsDptSummary;
  vbar classDesc / noframe
    width=&width type=SUM 
    sumvar=classFreq outside=SUM
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
run;
quit;

title1 'From N07.MeetingsMoreClsDptSummary';
title2 '(WYSIWYG)';
proc print data=N07.MeetingsMoreClsDptSummary;
  var classOrd classDesc classFreq;
run;

  /* SIMPLIFY PROCESSING */

  /* Miron's code on page 62 WAS duplicated for comparison purposes
     to RPCT that follows. However permission has not been requested
     for including his code in this file. Therefore, his code was
     removed. */

%let result = %getBarInfo(Xorigin=15, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=graycc; 
axis1 label=NONE
  order=(0 to 50 by 10) minor=(n=4) origin=(15pct, 18pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(15pct, 18pct);
title1 move=(+9pct,+0pct) 'Percentage of Meeting Hours';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt11_3.emf';
goptions htext=15pt htitle=17pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigClsDptSummary;
  vbar classDesc / noframe
    width=&width type=SUM 
    sumvar=RPct outside=SUM
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
    format Rpct pctIntfm.;
run;
quit;

/* FREQUENCY, SUM, PERCENT, MEAN CHARTS CODE SIMILARLY */
%let result = %getBarInfo(Xorigin=15, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=graycc; 
axis1 label=(f="Arial/Bold" a=90 "Frequency")
  order=(0 to 14 by 2) minor=(n=1) origin=(15pct, 18pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(15pct, 18pct);
title1 move=(+9pct,+0pct) 'Number of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt11_4.emf';
goptions htext=15pt htitle=17pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigClsDptSummary;
  vbar classDesc / noframe
    width=&width type=SUM 
    sumvar=ClassFreq outside=SUM
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
run;
quit;

%let result = %getBarInfo(Xorigin=15, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=graycc; 
axis1 label=(f="Arial/Bold" a=90 "Hours")
  order=(0 to 30 by 5) minor=(n=4) origin=(15pct, 18pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(15pct, 18pct);
title1 move=(+9pct,+0pct) 'Sum of Meeting Lengths by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt11_5.emf';
goptions htext=15pt htitle=17pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigClsDptSummary;
  vbar classDesc / noframe
    width=&width type=SUM 
    sumvar=sum outside=SUM
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
run;
quit;

%let result = %getBarInfo(Xorigin=15, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=graycc; 
axis1 label=NONE
  order=(0 to 50 by 10) minor=(n=4) origin=(15pct, 18pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(15pct, 18pct);
title1 move=(+9pct,+0pct) 'Percent of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt11_6.emf';
goptions htext=15pt htitle=17pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigClsDptSummary;
  vbar classDesc / noframe
    width=&width type=SUM 
    sumvar=oapct outside=SUM
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
    format oapct pctRfm.;
run;
quit;

%let result = %getBarInfo(Xorigin=15, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=graycc; 
axis1 label=(f="Arial/Bold" a=90 "Hours")
  order=(0 to 3 by 1) minor=(n=3) origin=(15pct, 18pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(15pct, 18pct);
title1 move=(+9pct,+0pct) 'Average Meeting Length by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt11_7.emf';
goptions htext=15pt htitle=17pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigClsDptSummary;
  vbar classDesc / noframe
    width=&width type=SUM 
    sumvar=mean outside=SUM
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
run;
quit;

/* PERCENT GRAPHS NOT DIRECTLY AVAILABLE IN GCHART */
/* G100 PERCENT  -- IS AVAILABLE*/
%let result = %getBarInfo(Xorigin=15, SpaceSz=2, GspaceSz=3, Ngrps=3, Nbars=9, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
pattern3 color=CXA9DFA9;
axis1 label=NONE
  order=(0 to 75 by 15) minor=(n=2) origin=(15pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Room") origin=(15pct, 17pct);
axis3 label=(f="Arial/Bold" "Dept") offset=(0.5 pct, 0.5 pct);

title1 move=(+9pct,+0pct) 'Percent of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt12_1.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=n07.MeetingsOrigGrpSummary;
  vbar classDesc / noframe
    width=&width gspace=&gspace type=SUM group=groupDesc
    sumvar=G100Pct outside=SUM patternID=group
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
    format groupDesc $dpt2Lfm.;
    format G100Pct pctIntfm.;
run;
quit;

/* MP100 PERCENT */
%let result = %getBarInfo(Xorigin=15, SpaceSz=2, GspaceSz=3, Ngrps=3, Nbars=9, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
pattern3 color=CXA9DFA9;
axis1 label=NONE
  order=(0 to 75 by 15) minor=(n=2) origin=(15pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Room") origin=(15pct, 17pct);
axis3 label=(f="Arial/Bold" "Dept") offset=(0.5 pct, 0.5 pct);

title1 move=(+9pct,+0pct) 'Percent of Meetings by Room';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt12_2.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=n07.MeetingsOrigGrpSummary;
  vbar classDesc / noframe PATTERNID=MIDPOINT
    width=&width gspace=&gspace type=SUM group=groupDesc
    sumvar=MP100Pct outside=SUM
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
    format groupDesc $dpt2Lfm.;
    format MP100Pct pctIntfm.;
run;
quit;

  /* SUBGROUP MP100%*/
%let result = %getBarInfo(Xorigin=13, SpaceSz=8, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
pattern3 color=CXA9DFA9;
legend1
  across=3 shape=bar(2.5,1.5) label=(h=13 pt "Room" h=11 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=9pt 'B100' 'C301' 'C339');

axis1 label=NONE
   style=0 order=(0 to 112 by 1) major=none minor=none value=none label=none 
   origin=(13pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(13pct, 17pct);
title1 move=(+9pct,+0pct) 'Percent of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt12_3.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigSgrpSummary;
  vbar classDesc / noframe
    width=&width type=SUM 
    subgroup=subgroupDesc
    sumvar=mp100pct inside=SUM 
    raxis=axis1 maxis=axis2
    legend=legend1
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
    format mp100pct pctIntfm.;
run;
quit;

  /* SUBGROUP sg100%*/
%let result = %getBarInfo(Xorigin=13, SpaceSz=8, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
pattern3 color=CXA9DFA9;
legend1
  across=3 shape=bar(2.5,1.5) label=(h=13 pt "Room" h=11 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=9pt 'B100' 'C301' 'C339');

axis1 label=NONE
   style=0 order=(0 to 112 by 1) major=none minor=none value=none label=none 
   origin=(13pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(13pct, 17pct);
title1 move=(+9pct,+0pct) 'Percent of Meetings by Room';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt12_4.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigSgrpSummary;
  vbar classDesc / noframe
    subgroup=subgroupDesc
    width=&width type=SUM 
    sumvar=sg100pct inside=SUM 
    raxis=axis1 maxis=axis2
    legend=legend1
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
    format sg100pct pctIntfm.;
run;
quit;

 /* RE-CREATE A NON-HIERARCHICAL GROUP BAR CHART WITH A SUBSET OF SASHELP.CLASS IN SUMMARY FORMAT*/
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt12_5.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

pattern1 color=pink; 
pattern2 color=blue; 
 
axis1 label=(a=90 f="Arial/Bold" "Height (inches)") 
 order=(50 to 70 by 5) minor=(n=4);
axis2 label=NONE value=NONE;
axis3 label=none value=(f="Arial/Bold" "Girls" "Boys");

title1 move=(+6pct,+0pct) 'Height by Gender';
title2 move=(+6pct,+0pct)'(for SASHELP.Class students ages 13-15)';
proc gchart data=N07.sasClass;
  vbar Name / 
    width=5 type=SUM sumvar=Height outside=SUM
    Group=sex patternID=group NOZERO
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
run;
quit;

  /* ERROR-BAR CHARTS */
  /* WITH GCHART AND RAW DATA */

/* 1) BOTH -- NO LEGEND, WHAT DOES 'C' AND 'N' STAND FOR? */
%let result = %getBarInfo(Xorigin=13, SpaceSz=1, GspaceSz=4, Ngrps=5, Nbars=10, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
axis1 label=( a=90 f="Arial/Bold" "Lab1 - Lab2") order=(-120 to 120 by 60) minor=(n=2);
axis2 label=(h=10Pt f="Arial/Bold" "Dx Cat");
axis3 label=(h=10Pt f="Arial/Bold" "Hospital ID") offset=(0.5 pct, 0.5 pct);

title1 move=(+8pct,+0pct) 'Average Difference in Lab Scores by Diagnostic Category';
title2 move=(+8pct,+0pct) '(With 95% Confidence Limits)';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt13_1.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;
proc gchart data=N07.biomed;
  vbar diagCat /noframe
    width=&width gspace=&gspace type=MEAN
    errorbar=Both clm=95 sumvar=Diff
    raxis=axis1 maxis=axis2 gaxis=axis3
    Group=Hospital patternID=midpoint
    coutline=black woutline=1;
run;
quit;

/* 2) TOP -- DO NOT WORK WITH POSITIVE AND NEGATIVE DATA */
%let result = %getBarInfo(Xorigin=13, SpaceSz=1, GspaceSz=4, Ngrps=5, Nbars=10, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
axis1 label=( a=90 f="Arial/Bold" "Lab1 - Lab2") order=(-120 to 120 by 60) minor=(n=2);
axis2 label=(h=10Pt f="Arial/Bold" "Dx Cat");
axis3 label=(h=10Pt f="Arial/Bold" "Hospital ID") offset=(0.5 pct, 0.5 pct);

title1 move=(+8pct,+0pct) 'Average Difference in Lab Scores by Diagnostic Category';
title2 move=(+8pct,+0pct) '(With 95% Confidence Limits)';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt13_2.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;
proc gchart data=N07.biomed;
  vbar diagCat /noframe
    width=&width gspace=&gspace type=MEAN
    errorbar=TOP clm=95 sumvar=Diff
    raxis=axis1 maxis=axis2 gaxis=axis3
    Group=Hospital patternID=midpoint
    coutline=black woutline=1;
run;
quit;

  /* ERROR-BAR CHARTS */
  /* WITH MACRO and SUMMARY DATA*/
  /* BAR WIDTH CALCULATED ACCURATELY WHEN GROUP VARIABLES CONTAIN FEW CHARACTERS OR ARE NUMERIC*/

  /* 1) TOPS WITH POSITIVE|NEGATIVE DATA*/
%let result = %getBarInfo(Xorigin=13, SpaceSz=1, GspaceSz=4, Ngrps=5, Nbars=10, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');
%displayEbars(_indat=n07.biomedGrpSummary, _MpVar=classORD, _groupVar=groupORD, 
              _Rvar=MEAN, _loY=LCLM, _hiY=UCLM, _fatLine=&width, _EbarType=TOP);

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
legend1
  across=1 shape=bar(3,2) label=NONE
  position=(top inside right) mode=share
  value=(h=11pt 'Carrier' 'Normal');

axis1 label=( a=90 f="Arial/Bold" "Lab1 - Lab2") order=(-120 to 120 by 60) minor=(n=2);
axis2 label=none value=none;
axis3 label=(h=10Pt f="Arial/Bold" "Hospital ID") offset=(0.5 pct, 0.5 pct);

title1 move=(+8pct,+0pct) 'Average Difference in Lab Scores by Diagnostic Category';
title2 move=(+8pct,+0pct) '(With 95% Confidence Limits)';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt13_3.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;
proc gchart data=N07.biomedgrpSummary annotate=EBarAnno;
  vbar classORD /noframe discrete width=&width 
    gspace=&gspace type=SUM sumvar=MEAN
    Group=groupORD subgroup=classOrd legend=legend1
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
    format groupOrd hospfm.;
run;
quit;

  /* 2) BOTH WITH UNEVEN BARS. */
%let result = %getBarInfo(Xorigin=13, SpaceSz=1, GspaceSz=4, Ngrps=5, Nbars=10, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');
%displayEbars(_indat=n07.biomedGrpSummary, _MpVar=classORD, _groupVar=groupORD, 
              _Rvar=MEAN, _loY=MIN, _hiY=MAX, _fatLine=&width, _EbarType=BOTH);

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
legend1
  across=1 shape=bar(3,2) label=NONE
  position=(top inside right) mode=share
  value=(h=11pt 'Carrier' 'Normal');

axis1 label=( a=90 f="Arial/Bold" "Lab1 - Lab2") order=(-100 to 200 by 50) minor=(n=1);
axis2 label=none value=none;
axis3 label=(h=10Pt f="Arial/Bold" "Hospital ID") offset=(0.5 pct, 0.5 pct);

title1 move=(+8pct,+0pct) 'Average Difference in Lab Scores by Diagnostic Category';
title2 move=(+8pct,+0pct) '(With MIN|MAX Data Differences)';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt13_4.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;
proc gchart data=N07.biomedgrpSummary annotate=EBarAnno;
  vbar classORD /noframe discrete width=&width 
    gspace=&gspace type=SUM sumvar=MEAN
    Group=groupORD subgroup=classOrd legend=legend1
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
    format groupOrd hospfm.;
run;
quit;

%let result = %getBarInfo(Xorigin=17, SpaceSz=1, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');

%displayEbars(_indat=N07.MeetingsorigClsDptSummary, _MpVar=classDesc, _Rvar=MEAN, 
              _loY=loStd, _hiY=hiStd, _fatLine=&width, _ThinLine=2, _EbarType=TOP);

pattern1 color=graycc; 
axis1 label=(a=90 f="Arial/Bold" "Hours")
  order=(0 to 4 by 1) minor=(n=1) origin=(17pct, 18pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(17pct, 18pct);
title1 move=(+9pct,+0pct) 'Average Length of Meetings by Department';
title2 move=(+9pct,+0pct) '(+/- 1 STD)';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt13_5.emf';
goptions htext=15pt htitle=17pt gsfname=chrt;

proc gchart data=N07.MeetingsorigClsDptSummary annotate=EBarAnno;
  vbar classDesc / noframe
    width=&width type=SUM 
    sumvar=MEAN inside=MEAN
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
run;
quit;


%let result = %getBarInfo(Xorigin=13, SpaceSz=4, GspaceSz=0, Ngrps=1, Nbars=5, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');
%displayEbars(_indat=n07.biomedMPSummary, _MpVar=classORD, _Rvar=MEAN, 
              _loY=loStdErr, _hiY=hiStdErr, _fatLine=&width, _thinLine=1, _EbarType=BOTH);

pattern1 color=CXDFA9A9; 

axis1 label=( a=90 f="Arial/Bold" "Lab1 - Lab2") order=(-50 to 10 by 10) minor=(n=4);
axis2 label=(h=10Pt f="Arial/Bold" "Hospital ID");

title1 move=(+8pct,+0pct) 'Difference in First Two Lab Scores';
title2 move=(+8pct,+0pct) '(+/- 1 SEM)';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\chrt13_6.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;
proc gchart data=N07.biomedMPSummary annotate=EBarAnno;
  vbar classORD /noframe discrete width=&width 
    type=SUM sumvar=MEAN
    raxis=axis1 maxis=axis2
    coutline=black woutline=1;
    format classOrd hospfm.;
run;
quit;


  /* INSIDE|OUTSIDE */
%OutsideInside(_indat=N07.MeetingsOriggrpSummary, _MPvar=ClassDesc, _groupVar=GroupDesc,
               _sgroupVar=, _Rvar=g100pct, _outsideVar=g100pct, _insideVar=classFreq,  _textSize=4,
               _outsideFmt=pctRfm., _insideFmt=2.);

%let result = %getBarInfo(Xorigin=15, SpaceSz=2, GspaceSz=3, Ngrps=3, Nbars=9, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
pattern3 color=CXA9DFA9;
axis1 label=NONE
  order=(0 to 75 by 15) minor=(n=2) origin=(15pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Room") origin=(15pct, 17pct);
axis3 label=(f="Arial/Bold" "Dept") offset=(0.5 pct, 0.5 pct);

title1 move=(+9pct,+0pct) 'Percent of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\Chrt14_1.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=n07.MeetingsOrigGrpSummary annotate=OutInAnno;
  vbar classDesc / noframe
    width=&width gspace=&gspace type=SUM group=groupDesc
    sumvar=G100Pct patternID=group
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
    format groupDesc $dpt2Lfm.;
    format G100Pct pctIntfm.;
run;
quit;

%OutsideInside(_indat=N07.MeetingsOrigSgrpSummary, _MPvar=ClassDesc, _groupVar=, _sgroupVar=subGroupDesc,
               _Rvar=mp100pct, _outsideVar=, _insideVar=mp100pct,  _textSize=4.5,
               _insideFmt=pctRfm.);
  /* SUBGROUP MP100%*/
%let result = %getBarInfo(Xorigin=13, SpaceSz=8, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
pattern3 color=CXA9DFA9;
legend1
  across=3 shape=bar(2.5,1.5) label=(h=13 pt "Room" h=11 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=9pt 'B100' 'C301' 'C339');

axis1 label=NONE
   style=0 order=(0 to 115 by 1) major=none minor=none value=none label=none 
   origin=(13pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(13pct, 17pct);
title1 move=(+9pct,+0pct) 'Percent of Meetings by Department';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\Chrt14_2.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigSgrpSummary annotate=OutInAnno;
  vbar classDesc / noframe
    width=&width type=SUM 
    subgroup=subgroupDesc
    sumvar=mp100pct
    raxis=axis1 maxis=axis2
    legend=legend1
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
run;
quit;

%OutsideInside(_indat=N07.MeetingsOrigSgrpSummary, _MPvar=ClassDesc, _groupVar=, _sgroupVar=subGroupDesc,
               _Rvar=subgroupFreq, _outsideVar=, _insideVar=subgroupFreq,  _textSize=4,
               _insideFmt=3.);
%let result = %getBarInfo(Xorigin=13, SpaceSz=8, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
pattern3 color=CXA9DFA9;
legend1
  across=3 shape=bar(2.5,1.5) label=(h=13 pt "Room" h=11 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=9pt 'B100' 'C301' 'C339');

axis1 label=NONE
   style=0 order=(0 to 14 by 1) major=none minor=none value=none label=none 
   origin=(13pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(13pct, 17pct);
title1 move=(+9pct,+0pct) 'Frequency of Meetings by Department';
title2 move=(+9pct,+0pct) '(with annotate=OutInAnno)';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\Chrt14_3.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigSgrpSummary annotate=OutInAnno;
  vbar classDesc / noframe
    width=&width type=SUM 
    subgroup=subgroupDesc
    sumvar=subgroupFreq outside=sum
    raxis=axis1 maxis=axis2
    legend=legend1
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
run;
quit;

%let result = %getBarInfo(Xorigin=13, SpaceSz=8, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
pattern3 color=CXA9DFA9;
legend1
  across=3 shape=bar(2.5,1.5) label=(h=13 pt "Room" h=11 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=9pt 'B100' 'C301' 'C339');

axis1 label=NONE
   style=0 order=(0 to 14 by 1) major=none minor=none value=none label=none 
   origin=(13pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(13pct, 17pct);
title1 move=(+9pct,+0pct) 'Frequency of Meetings by Department';
title2 move=(+9pct,+0pct) '(with INSIDE=FREQ)';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\Chrt14_3bad.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigSgrpSummary;
  vbar classDesc / noframe
    width=&width type=SUM 
    subgroup=subgroupDesc
    sumvar=subgroupFreq outside=sum inside=freq
    raxis=axis1 maxis=axis2
    legend=legend1
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
run;
quit;

%OutsideInside(_indat=N07.MeetingsOrigSgrpSummary, _MPvar=ClassDesc, _groupVar=, _sgroupVar=subGroupDesc,
               _Rvar=subgroupFreq, _outsideVar=, _insideVar=sg100pct,  _textSize=4.5,
               _insideFmt=pctRfm.);
%let result = %getBarInfo(Xorigin=13, SpaceSz=8, GspaceSz=0, Ngrps=1, Nbars=3, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
pattern3 color=CXA9DFA9;
legend1
  across=3 shape=bar(2.5,1.5) label=(h=13 pt "Room" h=11 pt position=left j=c)
  position=(top inside left) mode=share
  value=(h=9pt 'B100' 'C301' 'C339');

axis1 label=NONE
   style=0 order=(0 to 14 by 1) major=none minor=none value=none label=none 
   origin=(13pct, 17pct) offset=(,1pct);
axis2 label=(f="Arial/Bold" "Department") origin=(13pct, 17pct);
title1 move=(+9pct,+0pct) 'Percent of Meetings by Room';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\Chrt14_4.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;

proc gchart data=N07.MeetingsOrigSgrpSummary annotate=OutInAnno;
  vbar classDesc / noframe
    width=&width type=SUM 
    subgroup=subgroupDesc
    sumvar=subgroupFreq outside=sum
    raxis=axis1 maxis=axis2
    legend=legend1
    coutline=black woutline=1;
    format classDesc $dpt2Lfm.;
run;
quit;

%OutsideInside(_indat=N07.biomedGrpSummary, _MPvar=ClassOrd, _groupVar=groupOrd,
               _Rvar=MEAN, _insideVar=MEAN,  _textSize=3.75,
               _insideFmt=5.1);

%let result = %getBarInfo(Xorigin=13, SpaceSz=1, GspaceSz=4, Ngrps=5, Nbars=10, LCOLfrac=0.75);
%let width=%scan(&result,1,':');
%let gspace=%scan(&result,2,':');
%displayEbars(_indat=n07.biomedGrpSummary, _MpVar=classORD, _groupVar=groupORD, 
              _Rvar=MEAN, _loY=LCLM, _hiY=UCLM, _fatLine=&width, _thinLine=0.6, _EbarType=TOP);

pattern1 color=CXDFA9A9; 
pattern2 color=graycd; 
legend1
  across=1 shape=bar(3,2) label=NONE
  position=(top inside right) mode=share
  value=(h=11pt 'Carrier' 'Normal');

axis1 label=( a=90 f="Arial/Bold" "Lab1 - Lab2") order=(-120 to 120 by 60) minor=(n=2);
axis2 label=none value=none;
axis3 label=(h=10Pt f="Arial/Bold" "Hospital ID") offset=(0.5 pct, 0.5 pct);

title1 move=(+8pct,+0pct) 'Average Difference in Lab Scores by Diagnostic Category';
title2 move=(+8pct,+0pct) '(With 95% Confidence Limits)';
filename chrt 'c:\N07\BetterBarChart\Paper\EMF\Chrt14_5.emf';
goptions htext=13pt htitle=15pt gsfname=chrt;
proc gchart data=N07.biomedgrpSummary annotate=OutInAnno;
  vbar classORD /noframe discrete width=&width annotate=EBarAnno
    gspace=&gspace type=SUM sumvar=MEAN
    Group=groupORD subgroup=classOrd legend=legend1
    raxis=axis1 maxis=axis2 gaxis=axis3
    coutline=black woutline=1;
    format groupOrd hospfm.;
run;
quit;
